@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.9 date 2003-12-23
+ * version 0.91 date 2003-12-29
  * Copyright (C) 2003 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -58,16 +58,16 @@ typedef struct s_proto_mcuf_hdr
 #define BLP_REFRESH_LEN 11
 #define EBLP_REFRESH "\xDE""\xAA""\xBF""\xCD""REFRESH256"
 #define EBLP_REFRESH_LEN 14
-#define MCUF_REFRESH "\xDE""\xAA""\xBF""\xCD""REFRESH_MCUF"
-#define MCUF_REFRESH_LEN 16
+#define MCUF_REFRESH "\x42""\x42""\x42""\x42""\0\0\0\0\0\0\0\0"
+#define MCUF_REFRESH_LEN 12
 
 //close messages
 #define BLP_CLOSE "\xDE""\xAA""\xBF""\xCD""CLOSE"
 #define BLP_CLOSE_LEN 9
 #define EBLP_CLOSE "\xDE""\xAA""\xBF""\xCD""CLOSE256"
 #define EBLP_CLOSE_LEN 9
-#define MCUF_CLOSE "\xDE""\xAA""\xBF""\xCD""CLOSE_MCUF"
-#define MCUF_CLOSE_LEN 9
+#define MCUF_CLOSE ""
+#define MCUF_CLOSE_LEN 0
 
 
 
